KataBankOCR
===========
My first code kata. Written to teach myself TDD and pytest.

You can find the kata specifications in kata.txt and the latest version at http://codingdojo.org/cgi-bin/index.pl?KataBankOCR

Installation::

  pip install KataBankOCR

Example Syntax::

  parse input.txt
  parse input.txt output.txt
  cat input.txt | parse -
  cat input.txt | parse - output.txt
  
Example Input Files::

  site-packages/parse/test/input_files/basic.txt
  site-packages/parse/test/input_files/advanced.txt

Tests::

  pip install pytest
  py.test lib/python2.7/site-packages/parse

Questions / Comments:
  KataBankOCR@JasonGreen.Name
